@@ -31,10 +31,10 @@ describe 'cloudkitty' do
           :rabbit_use_ssl                  => '<SERVICE DEFAULT>',
           :heartbeat_timeout_threshold     => '<SERVICE DEFAULT>',
           :heartbeat_rate                  => '<SERVICE DEFAULT>',
-          :heartbeat_in_pthread            => '<SERVICE DEFAULT>',
           :kombu_reconnect_delay           => '<SERVICE DEFAULT>',
           :kombu_failover_strategy         => '<SERVICE DEFAULT>',
           :amqp_durable_queues             => '<SERVICE DEFAULT>',
+          :amqp_auto_delete                => '<SERVICE DEFAULT>',
           :kombu_compression               => '<SERVICE DEFAULT>',
           :kombu_ssl_ca_certs              => '<SERVICE DEFAULT>',
           :kombu_ssl_certfile              => '<SERVICE DEFAULT>',
@@ -43,9 +43,14 @@ describe 'cloudkitty' do
           :rabbit_ha_queues                => '<SERVICE DEFAULT>',
           :rabbit_retry_interval           => '<SERVICE DEFAULT>',
           :rabbit_quorum_queue             => '<SERVICE DEFAULT>',
+          :rabbit_qos_prefetch_count       => '<SERVICE DEFAULT>',
+          :rabbit_transient_quorum_queue   => '<SERVICE DEFAULT>',
+          :rabbit_transient_queues_ttl     => '<SERVICE DEFAULT>',
           :rabbit_quorum_delivery_limit    => '<SERVICE DEFAULT>',
           :rabbit_quorum_max_memory_length => '<SERVICE DEFAULT>',
           :rabbit_quorum_max_memory_bytes  => '<SERVICE DEFAULT>',
+          :use_queue_manager               => '<SERVICE DEFAULT>',
+          :rabbit_stream_fanout            => '<SERVICE DEFAULT>',
           :enable_cancel_on_failover       => '<SERVICE DEFAULT>',
         )
         is_expected.to contain_oslo__messaging__notifications('cloudkitty_config').with(
@@ -75,14 +80,19 @@ describe 'cloudkitty' do
           :rabbit_ha_queues                   => true,
           :rabbit_heartbeat_timeout_threshold => 60,
           :rabbit_heartbeat_rate              => 10,
-          :rabbit_heartbeat_in_pthread        => true,
           :rabbit_quorum_queue                => true,
+          :rabbit_qos_prefetch_count          => 10,
+          :rabbit_transient_quorum_queue      => false,
+          :rabbit_transient_queues_ttl        => 60,
           :rabbit_quorum_delivery_limit       => 3,
           :rabbit_quorum_max_memory_length    => 5,
           :rabbit_quorum_max_memory_bytes     => 1073741824,
+          :rabbit_use_queue_manager           => true,
+          :rabbit_stream_fanout               => true,
           :rabbit_enable_cancel_on_failover   => false,
           :kombu_reconnect_delay              => 5.0,
           :amqp_durable_queues                => true,
+          :amqp_auto_delete                   => true,
           :kombu_compression                  => 'gzip',
           :package_ensure                     => '2012.1.1-15.el6',
           :default_transport_url              => 'rabbit://rabbit_user:password@localhost:5673',
@@ -106,15 +116,20 @@ describe 'cloudkitty' do
         is_expected.to contain_oslo__messaging__rabbit('cloudkitty_config').with(
           :heartbeat_timeout_threshold     => 60,
           :heartbeat_rate                  => 10,
-          :heartbeat_in_pthread            => true,
           :kombu_reconnect_delay           => 5.0,
           :amqp_durable_queues             => true,
+          :amqp_auto_delete                => true,
           :kombu_compression               => 'gzip',
           :rabbit_ha_queues                => true,
           :rabbit_quorum_queue             => true,
+          :rabbit_qos_prefetch_count       => 10,
+          :rabbit_transient_quorum_queue   => false,
+          :rabbit_transient_queues_ttl     => 60,
           :rabbit_quorum_delivery_limit    => 3,
           :rabbit_quorum_max_memory_length => 5,
           :rabbit_quorum_max_memory_bytes  => 1073741824,
+          :use_queue_manager               => true,
+          :rabbit_stream_fanout            => true,
           :enable_cancel_on_failover       => false,
         )
         is_expected.to contain_oslo__messaging__notifications('cloudkitty_config').with(
@@ -175,14 +190,14 @@ describe 'cloudkitty' do
       end
 
       it 'configures metrics.yml' do
-        is_expected.to contain_file('metrics.yml')
-          .with_ensure('present')
-          .with_path('/etc/cloudkitty/metrics.yml')
-          .with_selinux_ignore_defaults(true)
-          .with_mode('0640')
-          .with_owner('root')
-          .with_group('cloudkitty')
-          .with_tag('cloudkitty-yamls')
+        is_expected.to contain_file('metrics.yml').with(
+          :ensure => 'file',
+          :path   => '/etc/cloudkitty/metrics.yml',
+          :mode   => '0640',
+          :owner  => 'root',
+          :group  => 'cloudkitty',
+          :tag    => 'cloudkitty-yamls'
+        )
       end
     end
   end
